@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any, Dict, Tuple, Sequence
+from typing import Any, Dict, Tuple, Sequence, Literal
 
 from . import _google_terms as terms
 from .connection import SheetsConnection
@@ -256,7 +256,9 @@ class Tab(Component[TabCellFormatting, TabGridFormatting, TabTextFormatting]):
         )
 
     def get_data(
-        self, rng: FullRange | None = None, value_type: GoogleValueType = EffectiveVal
+        self,
+        rng: FullRange | str | None = None,
+        value_type: GoogleValueType = EffectiveVal,
     ) -> Tab:
         """
         Gets the data from the cells of this Tab.
@@ -279,7 +281,7 @@ class Tab(Component[TabCellFormatting, TabGridFormatting, TabTextFormatting]):
             Tab: This Tab.
 
         """
-        rng = self.full_range() if not rng else rng
+        rng = self.ensure_full_range(self.full_range(), rng)
         if not rng.tab_title:
             rng.tab_title = self._title
         self._values, self._formats = self._get_data(
@@ -290,26 +292,31 @@ class Tab(Component[TabCellFormatting, TabGridFormatting, TabTextFormatting]):
     def write_values(
         self,
         data: Sequence[Sequence[Any] | Dict[str, Any]],
-        rng: FullRange | None = None,
+        rng: FullRange | str | None = None,
+        mode: Literal["write", "w", "append", "a"] = "write",
     ) -> Tab:
         """
         Adds a request to write data. Tab.commit () to commit the requests.
 
         Args:
             data (Sequence[Sequence[Any] | Dict[str, Any]]): The data to write.
-                Each sequence or dictionary in the passed data is a row, with 
+                Each sequence or dictionary in the passed data is a row, with
                 each value in that sub-iterable being a column. Dictionary keys
                 will be used as a header row in the written data.
             rng (FullRange, optional): A specific range to write to,
                 starting with the top-left-most cell in the range, defaults to None,
                 which will write to the top-left-most cell of the Tab.
+            mode (Literal, optional): Whether to append the data after any
+                populated rows already present in the Tab or to write to the
+                passed rng. Overrides rng if specified. Defaults to "write".
 
         Returns:
             Tab: This Tab.
 
         """
-        rng = self.full_range() if not rng else rng
-        self._write_values(data, self._tab_id, rng.to_dict())
+        rng = self.ensure_full_range(self.full_range(), rng)
+        rng_dict = rng.to_dict() if mode in ["write", "w"] else None
+        self._write_values(data, self._tab_id, rng_dict)
         return self
 
     @classmethod
